-------------------------------------------------------
-- RGB table 9bit + latch
-- 2021/10/12
-------------------------------------------------------
library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_unsigned.all;

entity rgbtable9bitlatch2mask is
	port(
		data0	:in std_logic;
		data1	:in std_logic;
		data2	:in std_logic;
		data3	:in std_logic;
		outen :in std_logic;
		inmask:in std_logic;
		red0	:out std_logic;
		red1	:out std_logic;
		red2	:out std_logic;
		green0:out std_logic;
		green1:out std_logic;
		green2:out std_logic;
		blue0 :out std_logic;
		blue1 :out std_logic;
		blue2 :out std_logic
	);
end rgbtable9bitlatch2mask;

architecture rtl of rgbtable9bitlatch2mask is
	signal rom_adrs	:std_logic_vector(3 downto 0);
	signal rom_latch	:std_logic_vector(8 downto 0);
	signal out_en		:std_logic;
	signal out_mask	:std_logic;
	
	subtype rgb_data is std_logic_vector(8 downto 0);
	type rom is array (0 to 15) of rgb_data;
	constant rgb : rom := (
	"000000000","111000000","000111000","000000111",
	"111111000","111000111","000111111","111111111",
	"110111000","110000111","000111110","111110000",
	"111000110","000110111","110110110","000110000");

begin
	out_en <= outen;
	out_mask <=inmask;

	rom_adrs(0) <= data0;
	rom_adrs(1) <= data1;
	rom_adrs(2) <= data2;
	rom_adrs(3) <= data3;
	rom_latch <= rgb(conv_integer (rom_adrs)) when out_en='1' and out_mask='1' else "000000000";

	red0 <= rom_latch(8);
	red1 <= rom_latch(7);
	red2 <= rom_latch(6);
	green0 <= rom_latch(5);
	green1 <= rom_latch(4);
	green2 <= rom_latch(3);
	blue0 <= rom_latch(2);
	blue1 <= rom_latch(1);
	blue2 <= rom_latch(0);

end rtl;